@@ -26,7 +26,7 @@
 class QString;
 #include <QWidget>
 
-#include <ksystemtrayicon.h>
+#include <kstatusnotifieritem.h>
 
 class KMixWindow;
 class Mixer;
@@ -35,10 +35,11 @@ class Volume;
 
 namespace Phonon
 {
-       class MediaObject;
+    class MediaObject;
 }
 
-class KMixDockWidget : public KSystemTrayIcon  {
+class KMixDockWidget : public KStatusNotifierItem
+{
    Q_OBJECT
 
    friend class KMixWindow;
@@ -47,38 +48,39 @@ class KMixDockWidget : public KSystemTrayIcon  {
    explicit KMixDockWidget(KMixWindow *parent, QWidget *referenceWidget, bool volumePopup);
    ~KMixDockWidget();
 
-   bool eventFilter(QObject * obj, QEvent * e);
-
    void setErrorPixmap();
    void ignoreNextEvent();
    //ViewDockAreaPopup* getDockAreaPopup();
 
-   Mixer *m_mixer;
-   Phonon::MediaObject *_audioPlayer;
+ signals:
+   void newMasterSelected();
 
  public slots:
    void setVolumeTip();
    void updatePixmap();
+   void activate(const QPoint &pos);
 
  protected:
    void createMasterVolWidget();
    void createActions();
-   void moveVolumePopoup();
-   void trayWheelEvent(QWheelEvent *);
 //    void trayToolTipEvent(QHelpEvent *e );
    void toggleMinimizeRestore();
-   bool event( QEvent *);
 
  private:
+   QWidget *_referenceWidget;
+   Phonon::MediaObject *_audioPlayer;
    bool _playBeepOnVolumeChange;
    bool _ignoreNextEvent;
    int  _oldToolTipValue;
    char _oldPixmapType;
    bool _volumePopup;
    KMixWindow* _kmixMainWindow;
+   Mixer *m_mixer;
+
  private slots:
    void dockMute();
-   void kmixSystrayAction(QSystemTrayIcon::ActivationReason);
+   void trayWheelEvent(int delta);
+   //void kmixSystrayAction(QSystemTrayIcon::ActivationReason);
    void selectMaster();
    void handleNewMaster(QString& soundcard_id, QString& channel_id);
    void contextMenuAboutToShow();
