@@ -19,34 +19,23 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef MIXDEVICEWIDGET_H
 #define MIXDEVICEWIDGET_H
 
-#include <kpanelapplet.h>
-
-#include <qwidget.h>
+#include <QWidget>
 #include "volume.h"
-#include <qptrlist.h>
 #include <qpixmap.h>
-#include <qrangecontrol.h>
 
-class QBoxLayout;
-class QLabel;
-class QPopupMenu;
-class QSlider;
 
 class KLed;
-class KLedButton;
 class KAction;
 class KActionCollection;
-class KSmallSlider;
-class KGlobalAccel;
+class KShortcutsDialog;
 
 class MixDevice;
-class VerticalText;
 class Mixer;
 class ViewBase;
 
@@ -56,30 +45,26 @@ class MixDeviceWidget
       Q_OBJECT
 
 public:
-    enum ValueStyle { NNONE = 0, NABSOLUTE = 1, NRELATIVE = 2 } ;
-
-      MixDeviceWidget( Mixer *mixer, MixDevice* md,
-                       bool small, Qt::Orientation orientation,
-                       QWidget* parent = 0, ViewBase* mw = 0, const char* name = 0);
+    MixDeviceWidget( MixDevice* md,
+                     bool small, Qt::Orientation orientation,
+                     QWidget* parent = 0, ViewBase* mw = 0 );
     ~MixDeviceWidget();
 
     void addActionToPopup( KAction *action );
 
     virtual bool isDisabled() const;
-    MixDevice* mixDevice() { return m_mixdevice; };
+    MixDevice* mixDevice() { return m_mixdevice; }
 
     virtual void setColors( QColor high, QColor low, QColor back );
     virtual void setIcons( bool value );
     virtual void setMutedColors( QColor high, QColor low, QColor back );
 
-    virtual bool isStereoLinked() const { return false; };
-    //virtual bool isLabeled() const { return false; };
-    virtual void setStereoLinked( bool ) {};
+    virtual bool isStereoLinked() const { return false; }
+    virtual void setStereoLinked( bool ) {}
     virtual void setLabeled( bool );
-    virtual void setTicks( bool ) {};
-    virtual void setValueStyle( ValueStyle ) {};
+    virtual void setTicks( bool ) {}
+    const QString& iconName() const;
 
-    virtual KGlobalAccel *keys(void);
 
 public slots:
     virtual void setDisabled( bool value );
@@ -87,26 +72,21 @@ public slots:
     virtual void update();
     virtual void showContextMenu();
 
-signals:
-    void newVolume( int num, Volume volume );
-    void newMasterVolume( Volume volume );
-    void masterMuted( bool );
-    void newRecsrc( int num, bool on );
-
 protected slots:
     void volumeChange( int );
     virtual void setVolume( int channel, int volume );
     virtual void setVolume( Volume volume );
 
 protected:
-      Mixer*               m_mixer;
       MixDevice*           m_mixdevice;
       KActionCollection*   _mdwActions;
-      KGlobalAccel*        m_keys;
-      ViewBase*            m_mixerwidget;
+      KActionCollection*   _mdwPopupActions;
+      ViewBase*            m_view;
       bool                 m_disabled;
       Qt::Orientation      _orientation;
       bool                 m_small;
+      KShortcutsDialog*    m_shortcutsDialog;
+      QString _iconName;
 
 private:
       void mousePressEvent( QMouseEvent *e );
