@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <sys/types.h>
@@ -30,8 +30,9 @@
 #include <stdlib.h>
 
 #include "mixer_sun.h"
-
-
+#include "mixer.h"
+#include <sys/soundcard.h>
+#include <QTimer>
 //======================================================================
 // CONSTANT/ENUM DEFINITIONS
 //======================================================================
@@ -113,10 +114,10 @@ const uint_t MixerSunPortMasks[] =
 // FUNCTION    : SUN_getMixer
 // DESCRIPTION : Creates and returns a new mixer object.
 //======================================================================
-Mixer_Backend* SUN_getMixer( int devnum )
+Mixer_Backend* SUN_getMixer( Mixer *mixer, int devnum )
 {
    Mixer_Backend *l_mixer;
-   l_mixer = new Mixer_SUN( devnum );
+   l_mixer = new Mixer_SUN( mixer, devnum );
    return l_mixer;
 }
 
@@ -125,7 +126,7 @@ Mixer_Backend* SUN_getMixer( int devnum )
 // FUNCTION    : Mixer::Mixer
 // DESCRIPTION : Class constructor.
 //======================================================================
-Mixer_SUN::Mixer_SUN(int devnum) : Mixer_Backend(devnum)
+Mixer_SUN::Mixer_SUN(Mixer *mixer, int devnum) : Mixer_Backend(mixer, devnum)
 {
    if ( devnum == -1 )
       m_devnum = 0;
@@ -135,7 +136,7 @@ Mixer_SUN::Mixer_SUN(int devnum) : Mixer_Backend(devnum)
 // FUNCTION    : Mixer::Mixer
 // DESCRIPTION : Class destructor.
 //======================================================================
-Mixer_SUN::~Mixer_SUN(int devnum) : Mixer_Backend(devnum)
+Mixer_SUN::~Mixer_SUN()
 {
    close();
 }
@@ -155,11 +156,12 @@ int Mixer_SUN::open()
    //
    // Open the mixer hardware driver
    //
-   QCString audiodev(getenv("AUDIODEV"));
+   QString audiodev(getenv("AUDIODEV"));
    if(audiodev.isNull())
      audiodev = "/dev/audio";
    audiodev += "ctl";
-   if ( ( fd = open( audiodev.data(), O_RDWR ) ) < 0 )
+   _udi = audiodev; // use device name as UDI. Doesn't matter as we only use it for hotplugging/unplugging.
+   if ( ( fd = ::open( audiodev.toAscii().data(), O_RDWR ) ) < 0 )
    {
       if ( errno == EACCES )
          return Mixer::ERR_PERM;
@@ -171,29 +173,37 @@ int Mixer_SUN::open()
       //
       // Mixer is open. Now define all of the mix devices.
       //
+	       int devmask, recmask, i_recsrc, stereodevs;
+      		// Mixer is open. Now define properties
+	      if (ioctl(fd, SOUND_MIXER_READ_DEVMASK, &devmask) == -1)
+	        return Mixer::ERR_READ;
+	      if (ioctl(fd, SOUND_MIXER_READ_RECMASK, &recmask) == -1)
+	        return Mixer::ERR_READ;
+	      if (ioctl(fd, SOUND_MIXER_READ_RECSRC, &i_recsrc) == -1)
+	        return Mixer::ERR_READ;
+	      if (ioctl(fd, SOUND_MIXER_READ_STEREODEVS, &stereodevs) == -1)
+	        return Mixer::ERR_READ;
 
-      if( m_mixDevices.isEmpty() )
-      {
          for ( int idx = 0; idx < numDevs; idx++ )
          {
-            Volume vol( 2, AUDIO_MAX_GAIN );
-            readVolumeFromHW( idx, vol );
-            MixDevice* md = new MixDevice( idx, vol, false, true,
+	    Volume::ChannelMask chnmask = Volume::MLEFT;
+            if ( stereodevs & ( 1 << idx ) ) chnmask = (Volume::ChannelMask)(chnmask|Volume::MRIGHT);
+
+            Volume playbackVol( chnmask, 100, 1, true, false );
+	    QString id;
+            id.setNum(idx);
+            MixDevice* md = new MixDevice( _mixer, id,
                QString(MixerDevNames[idx]), MixerChannelTypes[idx]);
-				md->setRecSource( isRecsrcHW( idx ) );
+            md->addPlaybackVolume(playbackVol);
+                  // Tutorial: Howto add a simple capture switch
+                  if ( recmask & ( 1 << idx ) ) {
+                     // can be captured => add capture volume, with no capture volume
+                     chnmask = Volume::MNONE;
+                     Volume captureVol( chnmask, 100, 1, true, true );
+                     md->addCaptureVolume(captureVol);
+                 }
             m_mixDevices.append( md );
          }
-     }
-     else
-     {
-        for( unsigned int idx = 0; idx < m_mixDevices.count(); idx++ )
-        {
-           MixDevice* md = m_mixDevices.at( idx );
-           if( !md )
-              return Mixer::ERR_INCOMPATIBLESET;
-           writeVolumeToHW( idx, md->getVolume() );
-        }
-     }
 
      m_mixerName = "SUN Audio Mixer";
      m_isOpen = true;
@@ -208,6 +218,7 @@ int Mixer_SUN::open()
 //======================================================================
 int Mixer_SUN::close()
 {
+   _pollingTimer->stop();
    m_isOpen = false;
    int l_i_ret = ::close( fd );
    m_mixDevices.clear();
@@ -237,14 +248,16 @@ QString Mixer_SUN::errorText( int mixer_error )
 
 
 //======================================================================
-// FUNCTION    : Mixer::readVolumeFrmoHW
+// FUNCTION    : Mixer::readVolumeFromHW
 // DESCRIPTION : Read the audio information from the driver.
 //======================================================================
-int Mixer_SUN::readVolumeFromHW( int devnum, Volume& volume )
+int Mixer_SUN::readVolumeFromHW( const QString& id, MixDevice *md )
 {
    audio_info_t audioinfo;
+   int devnum = id2num(id);
    uint_t devMask = MixerSunPortMasks[devnum];
 
+   Volume& volume = md->playbackVolume();
    //
    // Read the current audio information from the driver
    //
@@ -260,21 +273,21 @@ int Mixer_SUN::readVolumeFromHW( int devnum, Volume& volume )
       switch ( devnum )
       {
          case MIXERDEV_MASTER_VOLUME :
-            volume.setMuted( audioinfo.output_muted );
+            //volume.setSwitchActivated( audioinfo.output_muted );
             GainBalanceToVolume( audioinfo.play.gain,
                                  audioinfo.play.balance,
                                  volume );
             break;
 
          case MIXERDEV_RECORD_MONITOR :
-            volume.setMuted(FALSE);
+            md->setMuted(false);
             volume.setAllVolumes( audioinfo.monitor_gain );
             break;
 
          case MIXERDEV_INTERNAL_SPEAKER :
          case MIXERDEV_HEADPHONE :
          case MIXERDEV_LINE_OUT :
-            volume.setMuted( (audioinfo.play.port & devMask) ? FALSE : TRUE );
+            md->setMuted( (audioinfo.play.port & devMask) ? false : true );
             GainBalanceToVolume( audioinfo.play.gain,
                                  audioinfo.play.balance,
                                  volume );
@@ -283,14 +296,14 @@ int Mixer_SUN::readVolumeFromHW( int devnum, Volume& volume )
          case MIXERDEV_MICROPHONE :
          case MIXERDEV_LINE_IN :
          case MIXERDEV_CD :
-            volume.setMuted( (audioinfo.record.port & devMask) ? FALSE : TRUE );
+            md->setMuted( (audioinfo.record.port & devMask) ? false : true );
             GainBalanceToVolume( audioinfo.record.gain,
                                  audioinfo.record.balance,
                                  volume );
             break;
 
          default :
-            return Mixer::ERR_NODEV;
+            return Mixer::ERR_READ;
       }
       return 0;
    }
@@ -300,17 +313,19 @@ int Mixer_SUN::readVolumeFromHW( int devnum, Volume& volume )
 // FUNCTION    : Mixer::writeVolumeToHW
 // DESCRIPTION : Write the specified audio settings to the hardware.
 //======================================================================
-int Mixer_SUN::writeVolumeToHW( int devnum, Volume &volume )
+int Mixer_SUN::writeVolumeToHW( const QString& id, MixDevice *md )
 {
    uint_t gain;
    uchar_t balance;
    uchar_t mute;
 
+   Volume& volume = md->playbackVolume();
+   int devnum = id2num(id);
    //
    // Convert the Volume(left vol, right vol) to the Gain/Balance Sun uses
    //
    VolumeToGainBalance( volume, gain, balance );
-   mute = volume.isMuted() ? 1 : 0;
+   mute = md->isMuted() ? 1 : 0;
 
    //
    // Read the current audio settings from the hardware
@@ -362,7 +377,7 @@ int Mixer_SUN::writeVolumeToHW( int devnum, Volume &volume )
          break;
 
       default :
-         return Mixer::ERR_NODEV;
+         return Mixer::ERR_READ;
    }
 
    //
@@ -382,26 +397,27 @@ int Mixer_SUN::writeVolumeToHW( int devnum, Volume &volume )
 // FUNCTION    : Mixer::setRecsrcHW
 // DESCRIPTION :
 //======================================================================
-bool Mixer_SUN::setRecsrcHW( int /* devnum */, bool /* on */ )
+void Mixer_SUN::setRecsrcHW( const QString& /*id*/, bool /* on */ )
 {
-   return FALSE;
+   return;
 }
 
 //======================================================================
 // FUNCTION    : Mixer::isRecsrcHW
 // DESCRIPTION : Returns true if the specified device is a record source.
 //======================================================================
-bool Mixer_SUN::isRecsrcHW( int devnum )
+bool Mixer_SUN::isRecsrcHW( const QString& id )
 {
+   int devnum = id2num(id);
    switch ( devnum )
    {
       case MIXERDEV_MICROPHONE :
       case MIXERDEV_LINE_IN :
       case MIXERDEV_CD :
-         return TRUE;
+         return true;
 
       default :
-         return FALSE;
+         return false;
    }
 }
 
@@ -471,3 +487,8 @@ QString SUN_getDriverName() {
         return "SUNAudio";
 }
 
+QString Mixer_SUN::getDriverName()
+{
+        return "SUNAudio";
+}
+
