@@ -15,18 +15,19 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
-#include <kdebug.h>
-
 #include "asynccddbplookup.h"
 
+#include <kdebug.h>
+#include <ksocketfactory.h>
+
 namespace KCDDB
 {
   AsyncCDDBPLookup::AsyncCDDBPLookup()
-    : CDDBPLookup(), 
+    : CDDBPLookup(),
       state_(Idle)
   {
 
@@ -36,7 +37,7 @@ namespace KCDDB
   {
   }
 
-    CDDB::Result
+    Result
   AsyncCDDBPLookup::lookup
   (
     const QString         & hostname,
@@ -44,43 +45,30 @@ namespace KCDDB
     const TrackOffsetList & trackOffsetList
   )
   {
-    socket_ = new KNetwork::KBufferedSocket(hostname,QString::number(port));
-    
-    socket_->setBlocking( false );
+    socket_ = KSocketFactory::connectToHost("cddbp", hostname, port);
 
-    connect (socket_, SIGNAL(gotError(int)), SLOT(slotGotError(int)));
+    connect (socket_, SIGNAL(error(QAbstractSocket::SocketError)), SLOT(slotGotError(QAbstractSocket::SocketError)));
 
-    connect (socket_, SIGNAL( connected(const KResolverEntry &) ),
+    connect (socket_, SIGNAL(connected()),
       SLOT( slotConnectionSuccess() ) );
 
     connect (socket_, SIGNAL( readyRead() ), SLOT( slotReadyRead() ) );
 
-    if ( trackOffsetList.count() < 3 )
-      return UnknownError;
-
     trackOffsetList_ = trackOffsetList;
 
     state_ = WaitingForConnection;
 
-    if ( !socket_->connect(hostname, QString::number(port)) )
-    {
-       state_ = Idle;
-       emit finished( NoResponse );
-       return NoResponse;
-    }
-
     return Success;
   }
 
     void
-  AsyncCDDBPLookup::slotGotError(int error)
+  AsyncCDDBPLookup::slotGotError(QAbstractSocket::SocketError error)
   {
     state_ = Idle;
-    
-    if ( error == KNetwork::KSocketBase::LookupFailure )
+
+    if ( error == QAbstractSocket::HostNotFoundError )
       emit finished( HostNotFound );
-    else if ( error == KNetwork::KSocketBase::ConnectionTimedOut ||
-        error == KNetwork::KSocketBase::NetFailure )
+    else if ( error == QAbstractSocket::SocketTimeoutError )
       emit finished( NoResponse );
     else
       emit finished( UnknownError );
@@ -89,14 +77,14 @@ namespace KCDDB
     void
   AsyncCDDBPLookup::slotConnectionSuccess()
   {
-    kdDebug(60010) << "Connection successful" << endl;
+    kDebug(60010) << "Connection successful";
     state_ = WaitingForGreeting;
   }
 
     void
   AsyncCDDBPLookup::slotReadyRead()
   {
-    kdDebug(60010) << "Ready to read. State: " << stateToString() << endl;
+    kDebug(60010) << "Ready to read. State: " << stateToString();
 
     while ( Idle != state_ && isConnected() && socket_->canReadLine() )
       read();
@@ -209,11 +197,12 @@ namespace KCDDB
 
         state_ = Idle;
 
+        char c;
         while ( socket_->bytesAvailable() )
-          socket_->getch();
+          socket_->getChar(&c);
 
         close();
- 
+
         emit finished( result_ );
 
         break;
@@ -223,7 +212,7 @@ namespace KCDDB
         break;
     }
   }
-    
+
     QString
   AsyncCDDBPLookup::readLine()
   {
@@ -264,8 +253,7 @@ namespace KCDDB
       return;
     }
 
-    CDDBMatch match = matchList_.first();
-    matchList_.remove( match );
+    CDDBMatch match = matchList_.takeFirst();
 
     sendRead( match );
 
@@ -279,7 +267,9 @@ namespace KCDDB
 
     if (info.load( cdInfoBuffer_ ))
     {
-      info.category = category_;
+      info.set( "category", category_ );
+      info.set( "discid", discid_ );
+      info.set( "source", "freedb" );
       cdInfoList_.append( info );
     }
 
